@@ -159,7 +159,8 @@ static dc_status_t dt_libdc_buffer(unsigned char *ptr, int prf_length, int dc_mo
  * Parses a mem buffer extracting its data and filling a subsurface's dive structure.
  * Returns a pointer to last position in buffer, or NULL on failure.
  */
-static unsigned char *dt_dive_parser(unsigned char *runner, struct dive *dt_dive, struct dive_site_table *sites, long maxbuf)
+static unsigned char *dt_dive_parser(unsigned char *runner, struct dive *dt_dive, struct dive_site_table *sites,
+				     struct device_table *devices, long maxbuf)
 {
 	int  rc, profile_length, libdc_model;
 	char *tmp_notes_str = NULL;
@@ -176,6 +177,8 @@ static unsigned char *dt_dive_parser(unsigned char *runner, struct dive *dt_dive
 	char is_nitrox = 0, is_O2 = 0, is_SCR = 0;
 
 	device_data_t *devdata = calloc(1, sizeof(device_data_t));
+	devdata->sites = sites;
+	devdata->devices = devices;
 
 	/*
 	 * Parse byte to byte till next dive entry
@@ -565,7 +568,7 @@ static unsigned char *dt_dive_parser(unsigned char *runner, struct dive *dt_dive
 		dt_dive->dc.deviceid = 0;
 	else
 		dt_dive->dc.deviceid = 0xffffffff;
-	create_device_node(dt_dive->dc.model, dt_dive->dc.deviceid, "", "", dt_dive->dc.model);
+	create_device_node(devices, dt_dive->dc.model, dt_dive->dc.deviceid, "", "", dt_dive->dc.model);
 	dt_dive->dc.next = NULL;
 	if (!is_SCR && dt_dive->cylinders.nr > 0) {
 		get_cylinder(dt_dive, 0)->end.mbar = get_cylinder(dt_dive, 0)->start.mbar -
@@ -578,6 +581,7 @@ bail:
 	free(devdata);
 	return NULL;
 }
+
 /*
  * Parses the header of the .add file, returns the number of dives in
  * the archive (must be the same than number of dives in .log file).
@@ -598,9 +602,11 @@ static int wlog_header_parser (struct memblock *mem)
 	}
 }
 
+#define NOTES_LENGTH 256
+#define SUIT_LENGTH 26
 static void wlog_compl_parser(struct memblock *wl_mem, struct dive *dt_dive, int dcount)
 {
-	int strlong = 256, tmp = 0, offset = 12 + (dcount * 850),
+	int tmp = 0, offset = 12 + (dcount * 850),
 	    pos_weight =  offset + 256,
 	    pos_viz = offset + 258,
 	    pos_tank_init = offset + 266,
@@ -612,9 +618,10 @@ static void wlog_compl_parser(struct memblock *wl_mem, struct dive *dt_dive, int
 	 * Extended notes string. Fixed length 256 bytes. 0 padded if not complete
 	 */
 	if (*(runner + offset)) {
-		wlog_notes = calloc(strlong + 1, 1);
-		wlog_notes = memcpy(wlog_notes, runner + offset, 256);
-		wlog_notes = to_utf8((unsigned char *) wlog_notes);
+		char wlog_notes_temp[NOTES_LENGTH + 1];
+		wlog_notes_temp[NOTES_LENGTH] = 0;
+		(void)memcpy(wlog_notes_temp, runner + offset, NOTES_LENGTH);
+		wlog_notes = to_utf8((unsigned char *) wlog_notes_temp);
 	}
 	if (dt_dive->notes && wlog_notes) {
 		buffer = calloc (strlen(dt_dive->notes) + strlen(wlog_notes) + 1, 1);
@@ -660,11 +667,11 @@ static void wlog_compl_parser(struct memblock *wl_mem, struct dive *dt_dive, int
 	 * Dive suit, fixed length of 26 bytes, zero padded if shorter.
 	 * Expected to be preferred by the user if he did the work of setting it.
 	 */
-	strlong = 26;
 	if (*(runner + pos_suit)) {
-		wlog_suit = calloc(strlong, 1);
-		wlog_suit = memcpy(wlog_suit, runner + pos_suit, strlong);
-		wlog_suit = to_utf8((unsigned char *) wlog_suit);
+		char wlog_suit_temp[SUIT_LENGTH + 1];
+		wlog_suit_temp[SUIT_LENGTH] = 0;
+		(void)memcpy(wlog_suit_temp, runner + pos_suit, SUIT_LENGTH);
+		wlog_suit = to_utf8((unsigned char *) wlog_suit_temp);
 	}
 	if (wlog_suit)
 		dt_dive->suit = copy_string(wlog_suit);
@@ -675,7 +682,8 @@ static void wlog_compl_parser(struct memblock *wl_mem, struct dive *dt_dive, int
  * Main function call from file.c memblock is allocated (and freed) there.
  * If parsing is aborted due to errors, stores correctly parsed dives.
  */
-int datatrak_import(struct memblock *mem, struct memblock *wl_mem, struct dive_table *table, struct trip_table *trips, struct dive_site_table *sites)
+int datatrak_import(struct memblock *mem, struct memblock *wl_mem, struct dive_table *table, struct trip_table *trips,
+		    struct dive_site_table *sites, struct device_table *devices)
 {
 	UNUSED(trips);
 	unsigned char *runner;
@@ -707,7 +715,7 @@ int datatrak_import(struct memblock *mem, struct memblock *wl_mem, struct dive_t
 	while ((i < numdives) && ((long) runner < maxbuf)) {
 		struct dive *ptdive = alloc_dive();
 
-		runner = dt_dive_parser(runner, ptdive, sites, maxbuf);
+		runner = dt_dive_parser(runner, ptdive, sites, devices, maxbuf);
 		if (wl_mem)
 			wlog_compl_parser(wl_mem, ptdive, i);
 		if (runner == NULL) {
