@@ -2,6 +2,7 @@
 #ifndef GAS_H
 #define GAS_H
 
+#include "divemode.h"
 #include "units.h"
 
 #ifdef __cplusplus
@@ -10,6 +11,8 @@ extern "C" {
 #include <stdbool.h>
 #endif
 
+enum gas_component { N2, HE, O2 };
+
 // o2 == 0 && he == 0 -> air
 // o2 < 0 -> invalid
 struct gasmix {
@@ -41,12 +44,19 @@ static inline int get_he(struct gasmix mix)
 	return mix.he.permille;
 }
 
+static inline int get_n2(struct gasmix mix)
+{
+	return 1000 - get_o2(mix) - get_he(mix);
+}
+
 struct gas_pressures {
 	double o2, n2, he;
 };
 
 extern void sanitize_gasmix(struct gasmix *mix);
 extern int gasmix_distance(struct gasmix a, struct gasmix b);
+extern fraction_t get_gas_component_fraction(struct gasmix mix, enum gas_component component);
+extern void fill_pressures(struct gas_pressures *pressures, double amb_pressure, struct gasmix mix, double po2, enum divemode_t dctype);
 
 extern bool gasmix_is_air(struct gasmix gasmix);
 
