@@ -79,9 +79,7 @@ void init_qt_late()
 	QLocale::setDefault(loc);
 
 	QString translationLocation;
-#if defined(Q_OS_ANDROID)
-	translationLocation = QLatin1String("assets:/translations");
-#elif defined(Q_OS_IOS)
+#if defined(Q_OS_ANDROID) || defined(Q_OS_IOS)
 	translationLocation = QLatin1String(":/");
 #else
 	translationLocation = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
