@@ -1,12 +1,13 @@
 // SPDX-License-Identifier: GPL-2.0
 #include "TabDiveExtraInfo.h"
 #include "ui_TabDiveExtraInfo.h"
+#include "core/dive.h"
 #include "qt-models/divecomputerextradatamodel.h"
 
 TabDiveExtraInfo::TabDiveExtraInfo(QWidget *parent) :
 	TabBase(parent),
 	ui(new Ui::TabDiveExtraInfo()),
-	extraDataModel(new ExtraDataModel())
+	extraDataModel(new ExtraDataModel(this))
 {
 	ui->setupUi(this);
 	ui->extraData->setModel(extraDataModel);
@@ -19,11 +20,10 @@ TabDiveExtraInfo::~TabDiveExtraInfo()
 
 void TabDiveExtraInfo::updateData()
 {
-	extraDataModel->updateDive();
+	extraDataModel->updateDiveComputer(current_dc);
 }
 
 void TabDiveExtraInfo::clear()
 {
-	extraDataModel->updateDive();
+	extraDataModel->clear();
 }
-
