@@ -15,7 +15,6 @@
 
 #define COMBO_CHANGED 0
 #define TEXT_EDITED 1
-#define CSS_SET_HEADING_BLUE "QLabel { color: mediumblue;} "
 
 TabDiveInformation::TabDiveInformation(QWidget *parent) : TabBase(parent), ui(new Ui::TabDiveInformation())
 {
@@ -24,6 +23,7 @@ TabDiveInformation::TabDiveInformation(QWidget *parent) : TabBase(parent), ui(ne
 	connect(&diveListNotifier, &DiveListNotifier::cylinderAdded, this, &TabDiveInformation::cylinderChanged);
 	connect(&diveListNotifier, &DiveListNotifier::cylinderRemoved, this, &TabDiveInformation::cylinderChanged);
 	connect(&diveListNotifier, &DiveListNotifier::cylinderEdited, this, &TabDiveInformation::cylinderChanged);
+
 	QStringList atmPressTypes { "mbar", get_depth_unit() ,tr("Use DC")};
 	ui->atmPressType->insertItems(0, atmPressTypes);
 	pressTypeIndex = 0;
@@ -35,17 +35,6 @@ TabDiveInformation::TabDiveInformation(QWidget *parent) : TabBase(parent), ui(ne
 		types.append(gettextFromC::tr(divemode_text_ui[i]));
 	ui->diveType->insertItems(0, types);
 	connect(ui->diveType, SIGNAL(currentIndexChanged(int)), this, SLOT(diveModeChanged(int)));
-	QString CSSSetSmallLabel = "QLabel { color: mediumblue; font-size: " +                           // Using label height
-		QString::number((int)(0.5 + ui->diveHeadingLabel->geometry().height() * 0.66)) + "px;}"; // .. set CSS font size of star widget subscripts
-	ui->scrollAreaWidgetContents_3->setStyleSheet("QGroupBox::title { color: mediumblue;} ");
-	ui->diveHeadingLabel->setStyleSheet(CSS_SET_HEADING_BLUE);
-	ui->gasHeadingLabel->setStyleSheet(CSS_SET_HEADING_BLUE);
-	ui->environmentHeadingLabel->setStyleSheet(CSS_SET_HEADING_BLUE);
-	ui->groupBox_visibility->setStyleSheet(CSSSetSmallLabel);
-	ui->groupBox_current->setStyleSheet(CSSSetSmallLabel);
-	ui->groupBox_wavesize->setStyleSheet(CSSSetSmallLabel);
-	ui->groupBox_surge->setStyleSheet(CSSSetSmallLabel);
-	ui->groupBox_chill->setStyleSheet(CSSSetSmallLabel);
 	if (!prefs.extraEnvironmentalDefault) // if extraEnvironmental preference is turned off
 		showCurrentWidget(false, 0);  // Show current star widget at lefthand side
 	QAction *action = new QAction(tr("OK"), this);
@@ -233,7 +222,7 @@ void TabDiveInformation::updateData()
 		if (prefs.salinityEditDefault) {   //If edit-salinity is enabled then set correct water type in combobox:
 			ui->waterTypeCombo->setCurrentIndex(updateSalinityComboIndex(salinity_value));
 		} else {         // If water salinity is not editable: show water type as a text label
-                        ui->waterTypeText->setText(get_water_type_string(salinity_value));
+			ui->waterTypeText->setText(get_water_type_string(salinity_value));
 		}
 		ui->salinityText->setText(get_salinity_string(salinity_value));
 	} else {
@@ -255,6 +244,19 @@ void TabDiveInformation::updateData()
 		showCurrentWidget(false, 0);  // Show current star widget at lefthand side
 }
 
+void TabDiveInformation::updateUi(QString titleColor)
+{
+	QString CSSSetSmallLabel = "QLabel:enabled { color: ";
+	CSSSetSmallLabel.append(titleColor + "; font-size: ");
+	CSSSetSmallLabel.append(QString::number((int)(0.5 + ui->diveHeadingLabel->geometry().height() * 0.66)) + "px;}");
+	ui->groupBox_visibility->setStyleSheet(ui->groupBox_visibility->styleSheet() + CSSSetSmallLabel);
+	ui->groupBox_current->setStyleSheet(ui->groupBox_current->styleSheet() + CSSSetSmallLabel);
+	ui->groupBox_wavesize->setStyleSheet(ui->groupBox_wavesize->styleSheet() + CSSSetSmallLabel);
+	ui->groupBox_surge->setStyleSheet(ui->groupBox_surge->styleSheet() + CSSSetSmallLabel);
+	ui->groupBox_chill->setStyleSheet(ui->groupBox_chill->styleSheet() + CSSSetSmallLabel);
+	ui->salinityOverWrittenIcon->setToolTip(ui->salinityOverWrittenIcon->styleSheet() + CSSSetSmallLabel);
+}
+
 // From the index of the water type combo box, set the dive->salinity to an appropriate value
 void TabDiveInformation::on_waterTypeCombo_activated(int index)
 {
