@@ -16,17 +16,18 @@ public:
 	void setEvent(struct event *ev, struct gasmix lastgasmix);
 	struct event *getEvent();
 	void eventVisibilityChanged(const QString &eventName, bool visible);
-	void setVerticalAxis(DiveCartesianAxis *axis);
+	void setVerticalAxis(DiveCartesianAxis *axis, int speed);
 	void setHorizontalAxis(DiveCartesianAxis *axis);
 	void setModel(DivePlotDataModel *model);
 	bool shouldBeHidden();
 public
 slots:
-	void recalculatePos(bool instant = false);
+	void recalculatePos(int animationSpeed);
 
 private:
 	void setupToolTipString(struct gasmix lastgasmix);
 	void setupPixmap(struct gasmix lastgasmix);
+	int depthAtTime(int time);
 	DiveCartesianAxis *vAxis;
 	DiveCartesianAxis *hAxis;
 	DivePlotDataModel *dataModel;
