@@ -154,7 +154,6 @@ fi
 # normally this script builds the desktop version in subsurface/build
 # if the first argument is "-mobile" then build Subsurface-mobile in "$BUILD_PREFIX"build-mobile
 # if the first argument is "-both" then build both in subsurface/build and "$BUILD_PREFIX"build-mobile
-BUILDGRANTLEE=0
 
 if [ "$BUILD_MOBILE" = "1" ] ; then
 	echo "building Subsurface-mobile in ${SRC_DIR}/build-mobile"
@@ -171,9 +170,6 @@ if [ "$BUILD_DESKTOP" = "1" ] ; then
 	BUILDDIRS+=( "${BUILD_PREFIX}build" )
 	if [ "$BUILD_WITH_WEBKIT" = "1" ] ; then
 		PRINTING="-DNO_PRINTING=OFF"
-		if [ "$QUICK" != "1" ] ; then
-			BUILDGRANTLEE=1
-		fi
 	else
 		PRINTING="-DNO_PRINTING=ON"
 	fi
@@ -269,9 +265,12 @@ else
 		# maybe there's a system version that's new enough?
 		# Ugh that's uggly - read the ultimate filename, split at the last 'o' which gets us ".0.26.3" or ".1.0.0"
 		# since that starts with a dot, the field numbers in the cut need to be one higher
-		LIBGIT=$(realpath $(ldconfig -p | grep libgit2\\.so\\. | cut -d\  -f4) | awk -Fo '{ print $NF }')
-		LIBGITMAJ=$(echo $LIBGIT | cut -d. -f2)
-		LIBGIT=$(echo $LIBGIT | cut -d. -f3)
+		LDCONFIG=$(PATH=/sbin:/usr/sbin:$PATH which ldconfig)
+		if [ ! -z "$LDCONFIG" ] ; then
+			LIBGIT=$(realpath $("$LDCONFIG" -p | grep libgit2\\.so\\. | cut -d\  -f4) | awk -Fo '{ print $NF }')
+			LIBGITMAJ=$(echo $LIBGIT | cut -d. -f2)
+			LIBGIT=$(echo $LIBGIT | cut -d. -f3)
+		fi
 	fi
 fi
 
@@ -395,6 +394,16 @@ if [[ $PLATFORM = Darwin && "$BUILD_DEPS" == "1" ]] ; then
 	make install
 	popd
 
+	./${SRC_DIR}/scripts/get-dep-lib.sh single . libmtp
+	pushd libmtp
+	echo 'N' | NOCONFIGURE="1" bash ./autogen.sh
+	mkdir -p build
+	cd build
+	CFLAGS="$OLDER_MAC" ../configure --prefix="$INSTALL_ROOT"
+	make -j4
+	make install
+	popd
+
 	./${SRC_DIR}/scripts/get-dep-lib.sh single . libftdi1
 	pushd libftdi1
 	mkdir -p build
@@ -450,6 +459,8 @@ if [ "$PLATFORM" = Darwin ] ; then
 fi
 make -j4
 make install
+# make sure we know where the libdivecomputer.a was installed - sometimes it ends up in lib64, sometimes in lib
+STATIC_LIBDC="$INSTALL_ROOT/$(grep ^libdir Makefile | cut -d/ -f2)/libdivecomputer.a"
 
 if [ "$PLATFORM" = Darwin ] ; then
 	if [ -z "$CMAKE_PREFIX_PATH" ] ; then
@@ -486,22 +497,6 @@ else
 	EXTRA_OPTS="-DNO_USERMANUAL=ON"
 fi
 
-if [ "$BUILDGRANTLEE" = "1" ] ; then
-	# build grantlee
-	cd "$SRC"
-	./${SRC_DIR}/scripts/get-dep-lib.sh single . grantlee
-	pushd grantlee
-	mkdir -p build
-	cd build
-	cmake "$OLDER_MAC_CMAKE" -DCMAKE_BUILD_TYPE="$DEBUGRELEASE" \
-		-DCMAKE_INSTALL_PREFIX="$INSTALL_ROOT" \
-		-DBUILD_TESTS=NO \
-		"$SRC"/grantlee
-	make -j4
-	make install
-	popd
-fi
-
 if [ "$QUICK" != "1" ] ; then
 	# build the googlemaps map plugin
 
@@ -547,7 +542,7 @@ for (( i=0 ; i < ${#BUILDS[@]} ; i++ )) ; do
 		-DSUBSURFACE_TARGET_EXECUTABLE="$SUBSURFACE_EXECUTABLE" \
 		"$LIBGIT_ARGS" \
 		-DLIBDIVECOMPUTER_INCLUDE_DIR="$INSTALL_ROOT"/include \
-		-DLIBDIVECOMPUTER_LIBRARIES="$INSTALL_ROOT"/lib/libdivecomputer.a \
+		-DLIBDIVECOMPUTER_LIBRARIES="$STATIC_LIBDC" \
 		-DCMAKE_PREFIX_PATH="$CMAKE_PREFIX_PATH" \
 		-DBTSUPPORT="$BTSUPPORT" \
 		-DCMAKE_INSTALL_PREFIX="$INSTALL_ROOT" \
