@@ -67,13 +67,18 @@ void run_ui()
 	if (getAndroidHWInfo().contains("/OnePlus/")) {
 		QFontDatabase db;
 		int id = QFontDatabase::addApplicationFont(":/fonts/Roboto-Regular.ttf");
-		QString family = QFontDatabase::applicationFontFamilies(id).at(0);
-		QFont newDefaultFont;
-		newDefaultFont.setFamily(family);
-		(static_cast<QApplication *>(QCoreApplication::instance()))->setFont(newDefaultFont);
-		qDebug() << "Detected OnePlus device, trying to force bundled font" << family;
-		QFont defaultFont = (static_cast<QApplication *>(QCoreApplication::instance()))->font();
-		qDebug() << "Qt reports default font is set as" << defaultFont.family();
+		QStringList fontFamilies = QFontDatabase::applicationFontFamilies(id);
+		if (fontFamilies.count() > 0) {
+			QString family = fontFamilies.at(0);
+			QFont newDefaultFont;
+			newDefaultFont.setFamily(family);
+			(static_cast<QApplication *>(QCoreApplication::instance()))->setFont(newDefaultFont);
+			qDebug() << "Detected OnePlus device, trying to force bundled font" << family;
+			QFont defaultFont = (static_cast<QApplication *>(QCoreApplication::instance()))->font();
+			qDebug() << "Qt reports default font is set as" << defaultFont.family();
+		} else {
+			qDebug() << "Detected OnePlus device, but can't determine font family used";
+		}
 	}
 #endif
 	QScreen *appScreen = QApplication::screens().at(0);
