@@ -1,5 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0
 #include "testprofile.h"
+#include "core/device.h"
 #include "core/divesite.h"
 #include "core/trip.h"
 #include "core/file.h"
@@ -12,10 +13,9 @@
 // ..dives/exportprofilereference.csv) and copy the former over the later and commit that change
 // as well.
 
-
 void TestProfile::testProfileExport()
 {
-	parse_file("../dives/abitofeverything.ssrf", &dive_table, &trip_table, &dive_site_table);
+	parse_file("../dives/abitofeverything.ssrf", &dive_table, &trip_table, &dive_site_table, &device_table, &filter_preset_table);
 	save_profiledata("exportprofile.csv", false);
 	QFile org("../dives/exportprofilereference.csv");
 	org.open(QFile::ReadOnly);
