@@ -29,7 +29,6 @@ void TestQPrefTechnicalDetails::test_struct_get()
 	prefs.calcndltts = true;
 	prefs.dcceiling = true;
 	prefs.display_deco_mode = BUEHLMANN;
-	prefs.display_unused_tanks = true;
 	prefs.ead = true;
 	prefs.gfhigh = 27;
 	prefs.gflow = 25;
@@ -40,7 +39,6 @@ void TestQPrefTechnicalDetails::test_struct_get()
 	prefs.percentagegraph = true;
 	prefs.redceiling = true;
 	prefs.rulergraph = true;
-	prefs.show_average_depth = true;
 	prefs.show_ccr_sensors = true;
 	prefs.show_ccr_setpoint = true;
 	prefs.show_icd = true;
@@ -56,7 +54,6 @@ void TestQPrefTechnicalDetails::test_struct_get()
 	QCOMPARE(tst->calcndltts(), prefs.calcndltts);
 	QCOMPARE(tst->dcceiling(), prefs.dcceiling);
 	QCOMPARE(tst->display_deco_mode(), prefs.display_deco_mode);
-	QCOMPARE(tst->display_unused_tanks(), prefs.display_unused_tanks);
 	QCOMPARE(tst->ead(), prefs.ead);
 	QCOMPARE(tst->gfhigh(), prefs.gfhigh);
 	QCOMPARE(tst->gflow(), prefs.gflow);
@@ -67,7 +64,6 @@ void TestQPrefTechnicalDetails::test_struct_get()
 	QCOMPARE(tst->percentagegraph(), prefs.percentagegraph);
 	QCOMPARE(tst->redceiling(), prefs.redceiling);
 	QCOMPARE(tst->rulergraph(), prefs.rulergraph);
-	QCOMPARE(tst->show_average_depth(), prefs.show_average_depth);
 	QCOMPARE(tst->show_ccr_sensors(), prefs.show_ccr_sensors);
 	QCOMPARE(tst->show_ccr_setpoint(), prefs.show_ccr_setpoint);
 	QCOMPARE(tst->show_icd(), prefs.show_icd);
@@ -91,7 +87,6 @@ void TestQPrefTechnicalDetails::test_set_struct()
 	tst->set_calcndltts(false);
 	tst->set_dcceiling(false);
 	tst->set_display_deco_mode(RECREATIONAL);
-	tst->set_display_unused_tanks(false);
 	tst->set_ead(false);
 	tst->set_gfhigh(29);
 	tst->set_gflow(24);
@@ -102,7 +97,6 @@ void TestQPrefTechnicalDetails::test_set_struct()
 	tst->set_percentagegraph(false);
 	tst->set_redceiling(false);
 	tst->set_rulergraph(false);
-	tst->set_show_average_depth(false);
 	tst->set_show_ccr_sensors(false);
 	tst->set_show_ccr_setpoint(false);
 	tst->set_show_icd(false);
@@ -118,7 +112,6 @@ void TestQPrefTechnicalDetails::test_set_struct()
 	QCOMPARE(prefs.calcndltts, false);
 	QCOMPARE(prefs.dcceiling, false);
 	QCOMPARE(prefs.display_deco_mode, RECREATIONAL);
-	QCOMPARE(prefs.display_unused_tanks, false);
 	QCOMPARE(prefs.ead, false);
 	QCOMPARE(prefs.gfhigh, 29);
 	QCOMPARE(prefs.gflow, 24);
@@ -129,7 +122,6 @@ void TestQPrefTechnicalDetails::test_set_struct()
 	QCOMPARE(prefs.percentagegraph, false);
 	QCOMPARE(prefs.redceiling, false);
 	QCOMPARE(prefs.rulergraph, false);
-	QCOMPARE(prefs.show_average_depth, false);
 	QCOMPARE(prefs.show_ccr_sensors, false);
 	QCOMPARE(prefs.show_ccr_setpoint, false);
 	QCOMPARE(prefs.show_icd, false);
@@ -153,7 +145,6 @@ void TestQPrefTechnicalDetails::test_set_load_struct()
 	tst->set_calcndltts(false);
 	tst->set_dcceiling(true);
 	tst->set_display_deco_mode(RECREATIONAL);
-	tst->set_display_unused_tanks(false);
 	tst->set_ead(false);
 	tst->set_gfhigh(29);
 	tst->set_gflow(24);
@@ -164,7 +155,6 @@ void TestQPrefTechnicalDetails::test_set_load_struct()
 	tst->set_percentagegraph(false);
 	tst->set_redceiling(false);
 	tst->set_rulergraph(false);
-	tst->set_show_average_depth(true);
 	tst->set_show_ccr_sensors(true);
 	tst->set_show_ccr_setpoint(true);
 	tst->set_show_icd(true);
@@ -181,7 +171,6 @@ void TestQPrefTechnicalDetails::test_set_load_struct()
 	prefs.calcndltts = true;
 	prefs.dcceiling = false;
 	prefs.display_deco_mode = BUEHLMANN;
-	prefs.display_unused_tanks = true;
 	prefs.ead = true;
 	prefs.gfhigh = 27;
 	prefs.gflow = 25;
@@ -192,7 +181,6 @@ void TestQPrefTechnicalDetails::test_set_load_struct()
 	prefs.percentagegraph = true;
 	prefs.redceiling = true;
 	prefs.rulergraph = true;
-	prefs.show_average_depth = false;
 	prefs.show_ccr_sensors = false;
 	prefs.show_ccr_setpoint = false;
 	prefs.show_icd = false;
@@ -209,7 +197,6 @@ void TestQPrefTechnicalDetails::test_set_load_struct()
 	QCOMPARE(prefs.calcndltts, false);
 	QCOMPARE(prefs.dcceiling, true);
 	QCOMPARE(prefs.display_deco_mode, RECREATIONAL);
-	QCOMPARE(prefs.display_unused_tanks, false);
 	QCOMPARE(prefs.ead, false);
 	QCOMPARE((int)prefs.gfhigh, 29);
 	QCOMPARE((int)prefs.gflow, 24);
@@ -220,7 +207,6 @@ void TestQPrefTechnicalDetails::test_set_load_struct()
 	QCOMPARE(prefs.percentagegraph, false);
 	QCOMPARE(prefs.redceiling, false);
 	QCOMPARE(prefs.rulergraph, false);
-	QCOMPARE(prefs.show_average_depth, true);
 	QCOMPARE(prefs.show_ccr_sensors, true);
 	QCOMPARE(prefs.show_ccr_setpoint, true);
 	QCOMPARE(prefs.show_icd, true);
@@ -244,7 +230,6 @@ void TestQPrefTechnicalDetails::test_struct_disk()
 	prefs.calcndltts = true;
 	prefs.dcceiling = true;
 	prefs.display_deco_mode = BUEHLMANN;
-	prefs.display_unused_tanks = true;
 	prefs.ead = true;
 	prefs.gfhigh = 11;
 	prefs.gflow = 12;
@@ -255,7 +240,6 @@ void TestQPrefTechnicalDetails::test_struct_disk()
 	prefs.percentagegraph = true;
 	prefs.redceiling = true;
 	prefs.rulergraph = true;
-	prefs.show_average_depth = true;
 	prefs.show_ccr_sensors = true;
 	prefs.show_ccr_setpoint = true;
 	prefs.show_icd = true;
@@ -273,7 +257,6 @@ void TestQPrefTechnicalDetails::test_struct_disk()
 	prefs.calcndltts = false;
 	prefs.dcceiling = false;
 	prefs.display_deco_mode = RECREATIONAL;
-	prefs.display_unused_tanks = false;
 	prefs.ead = false;
 	prefs.gfhigh = 27;
 	prefs.gflow = 25;
@@ -284,7 +267,6 @@ void TestQPrefTechnicalDetails::test_struct_disk()
 	prefs.percentagegraph = false;
 	prefs.redceiling = false;
 	prefs.rulergraph = false;
-	prefs.show_average_depth = false;
 	prefs.show_ccr_sensors = false;
 	prefs.show_ccr_setpoint = false;
 	prefs.show_icd = false;
@@ -301,7 +283,6 @@ void TestQPrefTechnicalDetails::test_struct_disk()
 	QCOMPARE(prefs.calcndltts, true);
 	QCOMPARE(prefs.dcceiling, true);
 	QCOMPARE(prefs.display_deco_mode, BUEHLMANN);
-	QCOMPARE(prefs.display_unused_tanks, true);
 	QCOMPARE(prefs.ead, true);
 	QCOMPARE(prefs.gfhigh, 11);
 	QCOMPARE(prefs.gflow, 12);
@@ -312,7 +293,6 @@ void TestQPrefTechnicalDetails::test_struct_disk()
 	QCOMPARE(prefs.percentagegraph, true);
 	QCOMPARE(prefs.redceiling, true);
 	QCOMPARE(prefs.rulergraph, true);
-	QCOMPARE(prefs.show_average_depth, true);
 	QCOMPARE(prefs.show_ccr_sensors, true);
 	QCOMPARE(prefs.show_ccr_setpoint, true);
 	QCOMPARE(prefs.show_icd, true);
@@ -329,15 +309,13 @@ void TestQPrefTechnicalDetails::test_multiple()
 	// test multiple instances have the same information
 
 	prefs.gfhigh = 27;
-	auto tst_direct = new qPrefTechnicalDetails;
-
 	prefs.gflow = 25;
 	auto tst = qPrefTechnicalDetails::instance();
 
-	QCOMPARE(tst->gfhigh(), tst_direct->gfhigh());
-	QCOMPARE(tst->gflow(), tst_direct->gflow());
-	QCOMPARE(tst_direct->gfhigh(), 27);
-	QCOMPARE(tst_direct->gflow(), 25);
+	QCOMPARE(tst->gfhigh(), qPrefTechnicalDetails::gfhigh());
+	QCOMPARE(tst->gflow(), qPrefTechnicalDetails::gflow());
+	QCOMPARE(qPrefTechnicalDetails::gfhigh(), 27);
+	QCOMPARE(qPrefTechnicalDetails::gflow(), 25);
 }
 
 #define TEST(METHOD, VALUE)      \
@@ -401,10 +379,6 @@ void TestQPrefTechnicalDetails::test_oldPreferences()
 	TEST(tecDetails->zoomed_plot(), true);
 	tecDetails->set_show_sac(true);
 	TEST(tecDetails->show_sac(), true);
-	tecDetails->set_display_unused_tanks(true);
-	TEST(tecDetails->display_unused_tanks(), true);
-	tecDetails->set_show_average_depth(true);
-	TEST(tecDetails->show_average_depth(), true);
 	tecDetails->set_show_pictures_in_profile(true);
 	TEST(tecDetails->show_pictures_in_profile(), true);
 
@@ -440,10 +414,6 @@ void TestQPrefTechnicalDetails::test_oldPreferences()
 	TEST(tecDetails->zoomed_plot(), false);
 	tecDetails->set_show_sac(false);
 	TEST(tecDetails->show_sac(), false);
-	tecDetails->set_display_unused_tanks(false);
-	TEST(tecDetails->display_unused_tanks(), false);
-	tecDetails->set_show_average_depth(false);
-	TEST(tecDetails->show_average_depth(), false);
 	tecDetails->set_show_pictures_in_profile(false);
 	TEST(tecDetails->show_pictures_in_profile(), false);
 }
@@ -456,7 +426,6 @@ void TestQPrefTechnicalDetails::test_signals()
 	QSignalSpy spy4(qPrefTechnicalDetails::instance(), &qPrefTechnicalDetails::calcndlttsChanged);
 	QSignalSpy spy5(qPrefTechnicalDetails::instance(), &qPrefTechnicalDetails::dcceilingChanged);
 	QSignalSpy spy6(qPrefTechnicalDetails::instance(), &qPrefTechnicalDetails::display_deco_modeChanged);
-	QSignalSpy spy7(qPrefTechnicalDetails::instance(), &qPrefTechnicalDetails::display_unused_tanksChanged);
 	QSignalSpy spy8(qPrefTechnicalDetails::instance(), &qPrefTechnicalDetails::eadChanged);
 	QSignalSpy spy9(qPrefTechnicalDetails::instance(), &qPrefTechnicalDetails::gfhighChanged);
 	QSignalSpy spy10(qPrefTechnicalDetails::instance(), &qPrefTechnicalDetails::gflowChanged);
@@ -467,7 +436,6 @@ void TestQPrefTechnicalDetails::test_signals()
 	QSignalSpy spy15(qPrefTechnicalDetails::instance(), &qPrefTechnicalDetails::percentagegraphChanged);
 	QSignalSpy spy16(qPrefTechnicalDetails::instance(), &qPrefTechnicalDetails::redceilingChanged);
 	QSignalSpy spy17(qPrefTechnicalDetails::instance(), &qPrefTechnicalDetails::rulergraphChanged);
-	QSignalSpy spy18(qPrefTechnicalDetails::instance(), &qPrefTechnicalDetails::show_average_depthChanged);
 	QSignalSpy spy19(qPrefTechnicalDetails::instance(), &qPrefTechnicalDetails::show_ccr_sensorsChanged);
 	QSignalSpy spy20(qPrefTechnicalDetails::instance(), &qPrefTechnicalDetails::show_ccr_setpointChanged);
 	QSignalSpy spy21(qPrefTechnicalDetails::instance(), &qPrefTechnicalDetails::show_icdChanged);
@@ -489,8 +457,6 @@ void TestQPrefTechnicalDetails::test_signals()
 	prefs.dcceiling = true;
 	qPrefTechnicalDetails::set_dcceiling(false);
 	qPrefTechnicalDetails::set_display_deco_mode(VPMB);
-	prefs.display_unused_tanks = true;
-	qPrefTechnicalDetails::set_display_unused_tanks(false);
 	prefs.ead = true;
 	qPrefTechnicalDetails::set_ead(false);
 	qPrefTechnicalDetails::set_gfhigh(-29);
@@ -508,8 +474,6 @@ void TestQPrefTechnicalDetails::test_signals()
 	qPrefTechnicalDetails::set_redceiling(false);
 	prefs.rulergraph = true;
 	qPrefTechnicalDetails::set_rulergraph(false);
-	prefs.show_average_depth = true;
-	qPrefTechnicalDetails::set_show_average_depth(false);
 	prefs.show_ccr_sensors = true;
 	qPrefTechnicalDetails::set_show_ccr_sensors(false);
 	prefs.show_ccr_setpoint = true;
@@ -534,7 +498,6 @@ void TestQPrefTechnicalDetails::test_signals()
 	QCOMPARE(spy4.count(), 1);
 	QCOMPARE(spy5.count(), 1);
 	QCOMPARE(spy6.count(), 1);
-	QCOMPARE(spy7.count(), 1);
 	QCOMPARE(spy8.count(), 1);
 	QCOMPARE(spy9.count(), 1);
 	QCOMPARE(spy10.count(), 1);
@@ -545,7 +508,6 @@ void TestQPrefTechnicalDetails::test_signals()
 	QCOMPARE(spy15.count(), 1);
 	QCOMPARE(spy16.count(), 1);
 	QCOMPARE(spy17.count(), 1);
-	QCOMPARE(spy18.count(), 1);
 	QCOMPARE(spy19.count(), 1);
 	QCOMPARE(spy20.count(), 1);
 	QCOMPARE(spy21.count(), 1);
@@ -562,7 +524,6 @@ void TestQPrefTechnicalDetails::test_signals()
 	QVERIFY(spy4.takeFirst().at(0).toBool() == false);
 	QVERIFY(spy5.takeFirst().at(0).toBool() == false);
 	QVERIFY(spy6.takeFirst().at(0).toInt() == VPMB);
-	QVERIFY(spy7.takeFirst().at(0).toBool() == false);
 	QVERIFY(spy8.takeFirst().at(0).toBool() == false);
 	QVERIFY(spy9.takeFirst().at(0).toInt() == -29);
 	QVERIFY(spy10.takeFirst().at(0).toInt() == -24);
@@ -573,7 +534,6 @@ void TestQPrefTechnicalDetails::test_signals()
 	QVERIFY(spy15.takeFirst().at(0).toBool() == false);
 	QVERIFY(spy16.takeFirst().at(0).toBool() == false);
 	QVERIFY(spy17.takeFirst().at(0).toBool() == false);
-	QVERIFY(spy18.takeFirst().at(0).toBool() == false);
 	QVERIFY(spy19.takeFirst().at(0).toBool() == false);
 	QVERIFY(spy20.takeFirst().at(0).toBool() == false);
 	QVERIFY(spy21.takeFirst().at(0).toBool() == false);
